@@ -75,7 +75,7 @@ class ApmTransaction:
         if self.configured:
             self.transaction_name = transaction_name
             self.client = elasticapm.Client(self._apm_config)
-            elasticapm.instrument()
+            self.instrument()
             self.client.begin_transaction(transaction_type="Task")
             logger.info(f"APM Configured: config={self._apm_config}")
         else:
@@ -101,9 +101,43 @@ class ApmTransaction:
         result = "Success"
         if exc_type is not None:
             result = "Error"
+            self.client.capture_exception(handled=False)
         self.client.end_transaction(name=self.transaction_name, result=result)
         self.client.close()
 
+    @staticmethod
+    def instrument():
+        """
+        Vendored implementation of elasticapm.instrumentation.control.instrument changed to
+          omit certain frameworks
+        """
+        omit_frameworks = {
+            "elasticapm.instrumentation.packages.redis.RedisInstrumentation",
+            "elasticapm.instrumentation.packages.redis.RedisPipelineInstrumentation",
+            "elasticapm.instrumentation.packages.redis.RedisConnectionInstrumentation",
+            "elasticapm.instrumentation.packages.asyncio.aioredis.RedisConnectionPoolInstrumentation",
+            "elasticapm.instrumentation.packages.asyncio.aioredis.RedisPipelineInstrumentation",
+            "elasticapm.instrumentation.packages.asyncio.aioredis.RedisConnectionInstrumentation",
+        }
+
+        from elasticapm.instrumentation.control import _lock
+        from elasticapm.instrumentation.register import _cls_register
+        from elasticapm.instrumentation.register import _instrumentation_singletons
+        from elasticapm.instrumentation.register import import_string
+
+        # from elasticapm.instrumentation.control.instrument
+        with _lock:
+            # update to vendored code
+            filtered_cls_register = _cls_register.difference(omit_frameworks)
+            # from elasticapm.instrumentation.register.get_instrumentation_objects
+            for cls_str in filtered_cls_register:
+                if cls_str not in _instrumentation_singletons:
+                    cls = import_string(cls_str)
+                    _instrumentation_singletons[cls_str] = cls()
+                obj = _instrumentation_singletons[cls_str]
+                # from elasticapm.instrumentation.control.instrument
+                obj.instrument()
+
     def __enter__(self):
         return self
 
@@ -116,7 +150,9 @@ class TaskBase(ABC):
     """
     Generic wrapper for the DAG tasks providing a standard interface and execution flow.
     Each DAG task must implement its own subclass of this abstract wrapper class.
+
     Intended instantiation is as a context manager
+
     >>> class RealTask(TaskBase):
     >>>     def run(self):
     >>>         pass
@@ -126,17 +162,27 @@ class TaskBase(ABC):
 
     Task names in airflow are the same as the class name
     Additional methods can be added but will only be called if they are referenced via run,
-      pre_run, post_run, or __exit__
+    pre_run, post_run, or __exit__
 
-    overriding methods other than run, pre_run, post_run, and in
-      special cases __exit__ is discouraged as they are used internally to support the abstraction.
-      e.g. __init__ is called by the core api without user involvement so adding parameters will not
-      result in them being passed in as there is no client interface to __init__.
+    overriding methods other than run, pre_run, post_run, and in special cases __exit__ is
+    discouraged as they are used internally to support the abstraction.
+    e.g. __init__ is called by the core api without user involvement so adding parameters will not
+    result in them being passed in as there is no client interface to __init__.
 
     To use the apm infrastructure in subclass code one would do the following:
+
     >>> def foo(self):
     >>>     with self.apm_step("do detailed work"):
     >>>         pass # do work
+
+    Parameters
+    ----------
+    recipe_run_id : int
+        id of the recipe run used to identify the workflow run this task is part of
+    workflow_name : str
+        name of the workflow to which this instance of the task belongs
+    workflow_version : str
+        version of the workflow to which this instance of the task belongs
     """
 
     retries = 0
@@ -163,7 +209,7 @@ class TaskBase(ABC):
     def pre_run(self) -> None:
         """
         Method intended to be overridden that will execute prior to run() with Elastic APM span
-          capturing
+        capturing
         """
 
     @abstractmethod
@@ -175,14 +221,16 @@ class TaskBase(ABC):
     def post_run(self) -> None:
         """
         Method intended to be overridden that will execute after run() with Elastic APM span
-          capturing
+        capturing
         """
 
     def __call__(self) -> None:
         """
         The main executable function for the DAG task wrapper. Execution is instrumented with
-        Application Performance Monitoring if configured. The standard execution sequence is:\n
+        Application Performance Monitoring if configured. The standard execution sequence is:
+
         1 run
+
         2 record provenance
 
         Returns
@@ -191,11 +239,11 @@ class TaskBase(ABC):
         """
 
         logger.info(f"Task {self.task_name} started")
-        with self.apm_step("Pre Run"):
+        with self.apm_step("Pre Run", span_type="code.core", labels={"type": "core"}):
             self.pre_run()
-        with self.apm_step("Run"):
+        with self.apm_step("Run", span_type="code.core", labels={"type": "core"}):
             self.run()
-        with self.apm_step("Post Run"):
+        with self.apm_step("Post Run", span_type="code.core", labels={"type": "core"}):
             self.post_run()
         logger.info(f"Task {self.task_name} complete")
 
@@ -205,11 +253,11 @@ class TaskBase(ABC):
     def __exit__(self, exc_type, exc_val, exc_tb):
         """
         Method that can be overridden to execute teardown tasks after task execution regardless
-          of task execution success.  Only override this method with tasks that need to happen
-          regardless of tasks having an exception, ensure that no additional exception
-          will be raised, and always call super().__exit__
+        of task execution success.  Only override this method with tasks that need to happen
+        regardless of tasks having an exception, ensure that no additional exception
+        will be raised, and always call super().__exit__
         """
-        self.apm.close()
+        self.apm.close(exc_type=exc_type)
 
     def __repr__(self):
         return (
