@@ -1,7 +1,6 @@
 """
 Tests for the Workflow abstraction
 """
-from pathlib import Path
 from typing import Callable
 
 import pytest
@@ -16,31 +15,17 @@ def test_workflow_metadata(workflow):
     When: accessing attributes
     Then: Tha values are properly assigned
     """
-    workflow_instance, name, version = workflow
+    workflow_instance, category, name, version = workflow
 
-    instrument = name.split("_")[0]
-    calibration = "_".join(name.split("_")[1:])
-
-    assert workflow_instance.workflow_name == name
+    assert workflow_instance.workflow_name == f"{category}_{name}"
     assert workflow_instance.workflow_version == version
+    assert workflow_instance.workflow_package.startswith(__package__.split(".")[0])
     assert workflow_instance.nodes == []
     assert isinstance(workflow_instance._dag, DAG)
-    assert workflow_instance._dag.dag_id == f"{name}_{version}"
-    assert workflow_instance._instrument_name == instrument
-    assert workflow_instance._calibration_name == calibration
-    assert workflow_instance._dag_tags == f'["{instrument}", "{calibration}", "{version}"]'
-
-
-def test_workflow_bad_metadata():
-    """
-    Given: Workflow Class
-    When: Instance is created with non-convention workflow name
-    Then: Tags are expected unknown variants
-    """
-    name = "badname"
-    w = Workflow(workflow_name=name)
-    assert w._instrument_name == "InstrumentUnknown"
-    assert w._calibration_name == "CalibrationUnknown"
+    assert workflow_instance._dag.dag_id == f"{category}_{name}_{version}"
+    assert workflow_instance.process_category == category
+    assert workflow_instance.process_name == name
+    assert workflow_instance._dag_tags == f'["{category}", "{name}", "{version}"]'
 
 
 def test_workflow_add_node(workflow_tasks, workflow):
@@ -50,7 +35,7 @@ def test_workflow_add_node(workflow_tasks, workflow):
       structure of A >> [B, C] >> D
     Then: the dag object owned by the workflow has the right structure
     """
-    workflow_instance, name, version = workflow
+    workflow_instance, category, name, version = workflow
     TaskA, TaskB, TaskC, TaskD = workflow_tasks
     task_definitions = {
         TaskA: None,  # none
@@ -79,7 +64,7 @@ def test_workflow_add_node(workflow_tasks, workflow):
     assert len(workflow_instance.nodes) == 4
 
     for task in dag.tasks:
-        assert task.dag_id == f"{name}_{version}"
+        assert task.dag_id == f"{category}_{name}_{version}"
         assert task.upstream_task_ids == task_upstream_expectations[task.task_id]
 
 
@@ -89,7 +74,7 @@ def test_invalid_workflow_add_node(workflow):
     When: Adding the task to the workflow
     Then: Get a TypeError
     """
-    workflow_instance, _, _ = workflow
+    workflow_instance, _, _, _ = workflow
 
     class Task:
         pass
@@ -111,7 +96,7 @@ def test_tag_db_dunder(workflow, func: Callable, attr):
     When: retrieving dunder method that should be implemented
     Then: It is implemented
     """
-    workflow_instance, _, _ = workflow
+    workflow_instance, _, _, _ = workflow
 
     assert getattr(workflow_instance, attr, None)
     assert func(workflow_instance)
